@@ -189,9 +189,12 @@ REGISTER_AUDIO_DEVICE_TYPE("alsa", AudioDeviceAlsa);
  ****************************************************************************/
 
 AudioDeviceAlsa::AudioDeviceAlsa(const std::string& dev_name)
-  : AudioDevice(dev_name), play_handle(0), rec_handle(0), play_watch(0),
-    rec_watch(0), duplex(false)
+  : AudioDevice(dev_name), play_block_size(0), play_block_count(0),
+    rec_block_size(0), rec_block_count(0), play_handle(0), 
+    rec_handle(0), play_watch(0), rec_watch(0), duplex(false)
 {
+  assert(AudioDeviceAlsa_creator_registered);
+
   snd_pcm_t *play, *capture;
 
     // Open the device to check its duplex capability
@@ -213,14 +216,21 @@ AudioDeviceAlsa::AudioDeviceAlsa(const std::string& dev_name)
 
 AudioDeviceAlsa::~AudioDeviceAlsa(void)
 {
-  
+  closeDevice();
+  snd_config_update_free_global();
 } /* AudioDeviceAlsa::~AudioDeviceAlsa */
 
 
-int AudioDeviceAlsa::blocksize(void)
+int AudioDeviceAlsa::readBlocksize(void)
 {
-  return block_size;
-} /* AudioDeviceAlsa::blocksize */
+  return rec_block_size;
+} /* AudioDeviceAlsa::readBlocksize */
+
+
+int AudioDeviceAlsa::writeBlocksize(void)
+{
+  return play_block_size;
+} /* AudioDeviceAlsa::writeBlocksize */
 
 
 bool AudioDeviceAlsa::isFullDuplexCapable(void)
@@ -256,8 +266,16 @@ int AudioDeviceAlsa::samplesToWrite(void) const
   }
 
   int space_avail = snd_pcm_avail_update(play_handle);
-  return (space_avail < 0) ?
-            0 : (block_count * block_size) - space_avail;
+  if (space_avail < 0)
+  {
+    return 0;
+  }
+  int samples_to_write = (play_block_count * play_block_size) - space_avail;
+  if (samples_to_write < 0)
+  {
+    return 0;
+  }
+  return samples_to_write;
 
 } /* AudioDeviceAlsa::samplesToWrite */
 
@@ -291,6 +309,12 @@ bool AudioDeviceAlsa::openDevice(Mode mode)
       return false;
     }
 
+    if (!getBlockAttributes(play_handle, play_block_size, play_block_count))
+    {
+      closeDevice();
+      return false;
+    }
+
     play_watch = new AlsaWatch(play_handle);
     play_watch->activity.connect(
             mem_fun(*this, &AudioDeviceAlsa::writeSpaceAvailable));
@@ -322,6 +346,12 @@ bool AudioDeviceAlsa::openDevice(Mode mode)
       return false;
     }
 
+    if (!getBlockAttributes(rec_handle, rec_block_size, rec_block_count))
+    {
+      closeDevice();
+      return false;
+    }
+
     rec_watch = new AlsaWatch(rec_handle);
     rec_watch->activity.connect(
             mem_fun(*this, &AudioDeviceAlsa::audioReadHandler));
@@ -389,10 +419,10 @@ void AudioDeviceAlsa::audioReadHandler(FdWatch *watch, unsigned short revents)
 
   //printf("frames_avail=%d\n", frames_avail);
 
-  if (frames_avail >= block_size)
+  if (frames_avail >= rec_block_size)
   {
-    frames_avail /= block_size;
-    frames_avail *= block_size;
+    frames_avail /= rec_block_size;
+    frames_avail *= rec_block_size;
 
     int16_t buf[frames_avail * channels];
     memset(buf, 0, sizeof(buf));
@@ -406,7 +436,7 @@ void AudioDeviceAlsa::audioReadHandler(FdWatch *watch, unsigned short revents)
       }
       return;
     }
-    assert(frames_read == frames_avail);
+    assert(frames_read <= frames_avail);
 
     putBlocks(buf, frames_read);
   }
@@ -440,7 +470,7 @@ void AudioDeviceAlsa::writeSpaceAvailable(FdWatch *watch, unsigned short revents
       continue;
     }
 
-    int blocks_to_read = space_avail / block_size;
+    int blocks_to_read = space_avail / play_block_size;
     if (blocks_to_read == 0)
     {
       //printf("No free blocks available in sound card buffer\n");
@@ -457,7 +487,7 @@ void AudioDeviceAlsa::writeSpaceAvailable(FdWatch *watch, unsigned short revents
       return;
     }
     
-    int frames_to_write = blocks_avail * block_size;
+    int frames_to_write = blocks_avail * play_block_size;
     int frames_written = snd_pcm_writei(play_handle, buf, frames_to_write);
     //printf("frames_avail=%d  blocks_avail=%d  blocks_gotten=%d "
     //       "frames_written=%d\n", (int)frames_avail, blocks_avail,
@@ -545,7 +575,7 @@ bool AudioDeviceAlsa::initParams(snd_pcm_t *pcm_handle)
     return false;
   }
 
-  if (::abs(real_rate - sample_rate) > 100)
+  if (::abs(static_cast<int>(real_rate) - sample_rate) > 100)
   {
     cerr << "*** ERROR: The sample rate could not be set to "
          << sample_rate << "Hz for ALSA device \"" << dev_name << "\". "
@@ -603,9 +633,6 @@ bool AudioDeviceAlsa::initParams(snd_pcm_t *pcm_handle)
   snd_pcm_uframes_t ret_period_size, ret_buffer_size;
   snd_pcm_hw_params_get_period_size(hw_params, &ret_period_size, 0);
   snd_pcm_hw_params_get_buffer_size(hw_params, &ret_buffer_size);
-  
-  block_size = ret_period_size;
-  block_count = ret_buffer_size / ret_period_size;
 
   snd_pcm_hw_params_free(hw_params);
 
@@ -632,7 +659,7 @@ bool AudioDeviceAlsa::initParams(snd_pcm_t *pcm_handle)
   }
 
   err = snd_pcm_sw_params_set_start_threshold(pcm_handle, sw_params,
-					      (block_count - 1) * block_size);
+      (ret_buffer_size / ret_period_size - 1) * ret_period_size);
   if (err < 0)
   {
     cerr << "*** ERROR: Set start threshold failed: "
@@ -642,7 +669,7 @@ bool AudioDeviceAlsa::initParams(snd_pcm_t *pcm_handle)
     return false;
   }
 
-  err = snd_pcm_sw_params_set_avail_min(pcm_handle, sw_params, block_size);
+  err = snd_pcm_sw_params_set_avail_min(pcm_handle, sw_params, ret_period_size);
   if (err < 0)
   {
     cerr << "*** ERROR: Set min_avail threshold failed: "
@@ -668,6 +695,50 @@ bool AudioDeviceAlsa::initParams(snd_pcm_t *pcm_handle)
 } /* AudioDeviceAlsa::initParams */
 
 
+bool AudioDeviceAlsa::getBlockAttributes(snd_pcm_t *pcm_handle,
+                                         int &block_size, int &block_count)
+{
+  snd_pcm_hw_params_t *hw_params;
+  int err = snd_pcm_hw_params_malloc (&hw_params);
+  if (err < 0)
+  {
+    cerr << "*** ERROR: Allocate hardware parameter structure failed: "
+         << snd_strerror(err)
+         << endl;
+    return false;
+  }
+  err = snd_pcm_hw_params_current(pcm_handle, hw_params);
+  if (err < 0)
+  {
+    cerr << "*** ERROR: Failed to read current hardware params: "
+         << snd_strerror(err)
+         << endl;
+    return false;
+  }
+  snd_pcm_uframes_t ret_period_size, ret_buffer_size;
+  err = snd_pcm_hw_params_get_period_size(hw_params, &ret_period_size, 0);
+  if (err < 0)
+  {
+    cerr << "*** ERROR: Failed to get period size: "
+         << snd_strerror(err)
+         << endl;
+    return false;
+  }
+  err = snd_pcm_hw_params_get_buffer_size(hw_params, &ret_buffer_size);
+  if (err < 0)
+  {
+    cerr << "*** ERROR: Failed to get buffer size: "
+         << snd_strerror(err)
+         << endl;
+    return false;
+  }
+  snd_pcm_hw_params_free(hw_params);
+  block_size = ret_period_size;
+  block_count = ret_buffer_size / ret_period_size;
+  return true;
+} /* AudioDeviceAlsa::getBlockAttributes */
+
+
 bool AudioDeviceAlsa::startPlayback(snd_pcm_t *pcm_handle)
 {
   int err = snd_pcm_prepare(pcm_handle);
