@@ -111,7 +111,6 @@ class LocationInfo
   public:
     static LocationInfo* instance()
     {
-       static CGuard g;
        if (!_instance)
         return NULL; // illegal pointer, if not initialized
        return _instance;
@@ -122,6 +121,12 @@ class LocationInfo
         return _instance;
     }
 
+    static void deleteInstance(void)
+    {
+      delete _instance;
+      _instance = 0;
+    }
+
     struct Coordinate
     {
        explicit Coordinate(char d = 'N') : deg(0), min(0), sec(0), dir(d) {};
@@ -200,20 +205,6 @@ class LocationInfo
     void setTransmitting(const std::string &name, struct timeval tv, bool state);
     void setReceiving(const std::string &name, struct timeval tv, bool state);
 
-    class CGuard
-    {
-       public:
-         ~CGuard()
-         {
-           if(NULL != LocationInfo::_instance)
-           {
-              delete LocationInfo::_instance;
-              LocationInfo::_instance = NULL;
-           }
-         }
-    };
-    friend class CGuard;
-
   private:
     static LocationInfo* _instance;
     LocationInfo() : sequence(0), aprs_stats_timer(0), sinterval(0) {}
