@@ -202,7 +202,7 @@ bool NetUplink::initialize(void)
     mute_tx_timer->expired.connect(mem_fun(*this, &NetUplink::unmuteTx));
   }
   
-  server = new TcpServer(listen_port);
+  server = new TcpServer<>(listen_port);
   server->clientConnected.connect(mem_fun(*this, &NetUplink::clientConnected));
   server->clientDisconnected.connect(
       mem_fun(*this, &NetUplink::clientDisconnected));
@@ -239,6 +239,10 @@ bool NetUplink::initialize(void)
   {
     setFallbackActive(true);
   }
+  else
+  {
+    rx->setMuteState(Rx::MUTE_CONTENT);
+  }
 
   return true;
   
@@ -264,6 +268,7 @@ bool NetUplink::initialize(void)
 void NetUplink::handleIncomingConnection(TcpConnection *incoming_con)
 {
   assert(con == 0);
+  rx->reset();
   if (fallback_enabled) // Deactivate fallback repeater mode
   {
     setFallbackActive(false);
@@ -356,6 +361,10 @@ void NetUplink::disconnectCleanup(void)
   {
     setFallbackActive(true);
   }
+  else
+  {
+    rx->setMuteState(Rx::MUTE_CONTENT);
+  }
 } /* NetUplink::disconnectCleanup */
 
 
@@ -655,6 +664,7 @@ void NetUplink::sendMsg(Msg *msg)
     {
       cerr << "*** ERROR: TCP transmit error in NetUplink \"" << name
            << "\": " << strerror(errno) << ".\n";
+      forceDisconnect();
     }
     else if (written != static_cast<int>(msg->size()))
     {
@@ -791,10 +801,10 @@ void NetUplink::unmuteTx(Timer *t)
 
 void NetUplink::setFallbackActive(bool activate)
 {
+  rx->reset();
   if (activate)
   {
     cout << name << ": Activating fallback repeater mode\n";
-    rx->reset();
     tx->setTxCtrlMode(Tx::TX_AUTO);
     tx_selector->selectSource(loopback_con);
     rx->setMuteState(Rx::MUTE_NONE);
@@ -802,7 +812,6 @@ void NetUplink::setFallbackActive(bool activate)
   else
   {
     cout << name << ": Deactivating fallback repeater mode\n";
-    rx->reset();
     tx->setTxCtrlMode(Tx::TX_OFF);
     tx_selector->selectSource(fifo);
   }
