@@ -10,7 +10,7 @@ server core (e.g. via a TCP/IP network).
 
 \verbatim
 RemoteTrx - A remote receiver for the SvxLink server
-Copyright (C) 2003-2014 Tobias Blomberg / SM0SVX
+Copyright (C) 2003-2015 Tobias Blomberg / SM0SVX
 
 This program is free software; you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -46,12 +46,14 @@ Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #include <fcntl.h>
 #include <pwd.h>
 #include <grp.h>
+#include <errno.h>
 
 #include <iostream>
 #include <iomanip>
 #include <cstring>
 #include <cstdlib>
 #include <vector>
+#include <sstream>
 
 
 /****************************************************************************
@@ -332,6 +334,7 @@ int main(int argc, char **argv)
     fclose(pidfile);
   }
 
+  const char *home_dir = 0;
   if (runasuser != NULL)
   {
       // Setup supplementary group IDs
@@ -357,10 +360,14 @@ int main(int argc, char **argv)
       perror("setuid");
       exit(1);
     }
+    home_dir = passwd->pw_dir;
   }
 
-  const char *home_dir = getenv("HOME");
-  if (home_dir == NULL)
+  if (home_dir == 0)
+  {
+    home_dir = getenv("HOME");
+  }
+  if (home_dir == 0)
   {
     home_dir = ".";
   }
@@ -391,13 +398,19 @@ int main(int argc, char **argv)
 	cfg_filename = SYSCONF_INSTALL_DIR "/remotetrx.conf";
 	if (!cfg.open(cfg_filename))
 	{
-	  cerr << "*** ERROR: Could not open configuration file. Tried:\n"
+	  cerr << "*** ERROR: Could not open configuration file";
+          if (errno != 0)
+          {
+            cerr << " (" << strerror(errno) << ")";
+          }
+          cerr << ".\n";
+	  cerr << "Tried the following paths:\n"
       	       << "\t" << home_dir << "/.svxlink/remotetrx.conf\n"
       	       << "\t" SVX_SYSCONF_INSTALL_DIR "/remotetrx.conf\n"
 	       << "\t" SYSCONF_INSTALL_DIR "/remotetrx.conf\n"
 	       << "Possible reasons for failure are: None of the files exist,\n"
 	       << "you do not have permission to read the file or there was a\n"
-	       << "syntax error in the file\n";
+	       << "syntax error in the file.\n";
 	  exit(1);
 	}
       }
@@ -456,8 +469,8 @@ int main(int argc, char **argv)
   
   cfg.getValue("GLOBAL", "TIMESTAMP_FORMAT", tstamp_format);
   
-  cout << PROGRAM_NAME " v" REMOTE_TRX_VERSION " (" __DATE__ 
-          ") Copyright (C) 2003-2014 Tobias Blomberg / SM0SVX\n\n";
+  cout << PROGRAM_NAME " v" REMOTE_TRX_VERSION
+          " Copyright (C) 2003-2015 Tobias Blomberg / SM0SVX\n\n";
   cout << PROGRAM_NAME " comes with ABSOLUTELY NO WARRANTY. "
           "This is free software, and you are\n";
   cout << "welcome to redistribute it in accordance with the "
@@ -501,7 +514,11 @@ int main(int argc, char **argv)
     cout << "--- Using sample rate " << rate << "Hz\n";
   }
   
-  struct termios org_termios;
+  int card_channels = 2;
+  cfg.getValue("GLOBAL", "CARD_CHANNELS", card_channels);
+  AudioIO::setChannels(card_channels);
+
+  struct termios org_termios = {0};
   if (logfile_name == 0)
   {
     struct termios termios;
@@ -511,8 +528,6 @@ int main(int argc, char **argv)
     tcsetattr(STDIN_FILENO, TCSANOW, &termios);
 
     stdin_watch = new FdWatch(STDIN_FILENO, FdWatch::FD_WATCH_RD);
-    // must explicitly specify name space for ptr_fun() to avoid conflict
-    // with ptr_fun() in /usr/include/c++/4.5/bits/stl_function.h
     stdin_watch->activity.connect(sigc::ptr_fun(&stdinHandler));
   }
   
@@ -547,6 +562,14 @@ int main(int argc, char **argv)
     cerr << "*** ERROR: No trxs successfully initialized. Bailing out...\n";
   }
 
+  for (vector<TrxHandler*>::iterator it = trx_handlers.begin();
+       it != trx_handlers.end();
+       ++it)
+  {
+    delete *it;
+  }
+  trx_handlers.clear();
+
   logfile_flush();
   
   if (stdin_watch != 0)
@@ -768,10 +791,9 @@ static bool logfile_open(void)
   logfd = open(logfile_name, O_WRONLY | O_APPEND | O_CREAT, 00644);
   if (logfd == -1)
   {
-    char str[256] = "open(\"";
-    strcat(str, logfile_name);
-    strcat(str, "\")");
-    perror(str);
+    ostringstream ss;
+    ss << "open(\"" << logfile_name << "\")";
+    perror(ss.str().c_str());
     return false;
   }
 
@@ -785,14 +807,14 @@ static void logfile_reopen(const char *reason)
   logfile_write_timestamp();
   string msg(reason);
   msg += ". Reopening logfile\n";
-  write(logfd, msg.c_str(), msg.size());
+  if (write(logfd, msg.c_str(), msg.size()) == -1) {}
 
   logfile_open();
 
   logfile_write_timestamp();
   msg = reason;
   msg += ". Logfile reopened\n";
-  write(logfd, msg.c_str(), msg.size());
+  if (write(logfd, msg.c_str(), msg.size()) == -1) {}
 } /* logfile_reopen */
 
 
