@@ -148,6 +148,8 @@ EventHandler::EventHandler(const string& event_script, Logic *logic)
                     this, NULL);
   Tcl_CreateCommand(interp, "publishStateEvent", publishStateEventHandler,
                     this, NULL);
+  Tcl_CreateCommand(interp, "playDtmf", playDtmfHandler, this, NULL);
+  Tcl_CreateCommand(interp, "injectDtmf", injectDtmfHandler, this, NULL);
 
   setVariable("script_path", event_script);
 
@@ -271,26 +273,12 @@ const string EventHandler::eventResult(void) const
  *
  ****************************************************************************/
 
-
-/*
- *----------------------------------------------------------------------------
- * Method:    
- * Purpose:   
- * Input:     
- * Output:    
- * Author:    
- * Created:   
- * Remarks:   
- * Bugs:      
- *----------------------------------------------------------------------------
- */
-
 int EventHandler::playFileHandler(ClientData cdata, Tcl_Interp *irp, int argc,
       	      	      	   const char *argv[])
 {
   if(argc != 2)
   {
-    char msg[] = "Usage: playFile: <filename>";
+    static char msg[] = "Usage: playFile: <filename>";
     Tcl_SetResult(irp, msg, TCL_STATIC);
     return TCL_ERROR;
   }
@@ -309,7 +297,7 @@ int EventHandler::playSilenceHandler(ClientData cdata, Tcl_Interp *irp,
 {
   if(argc != 2)
   {
-    char msg[] = "Usage: playSilence <milliseconds>";
+    static char msg[] = "Usage: playSilence <milliseconds>";
     Tcl_SetResult(irp, msg, TCL_STATIC);
     return TCL_ERROR;
   }
@@ -327,7 +315,7 @@ int EventHandler::playToneHandler(ClientData cdata, Tcl_Interp *irp,
 {
   if(argc != 4)
   {
-    char msg[] = "Usage: playTone <fq> <amp> <milliseconds>";
+    static char msg[] = "Usage: playTone <fq> <amp> <milliseconds>";
     Tcl_SetResult(irp, msg, TCL_STATIC);
     return TCL_ERROR;
   }
@@ -348,7 +336,7 @@ int EventHandler::recordHandler(ClientData cdata, Tcl_Interp *irp,
   {
     if((argc < 2) || (argc > 3))
     {
-      char msg[] = "Usage: recordStart <filename> [max_time]";
+      static char msg[] = "Usage: recordStart <filename> [max_time]";
       Tcl_SetResult(irp, msg, TCL_STATIC);
       return TCL_ERROR;
     }
@@ -365,7 +353,7 @@ int EventHandler::recordHandler(ClientData cdata, Tcl_Interp *irp,
   {
     if(argc != 1)
     {
-      char msg[] = "Usage: recordStop";
+      static char msg[] = "Usage: recordStop";
       Tcl_SetResult(irp, msg, TCL_STATIC);
       return TCL_ERROR;
     }
@@ -384,7 +372,7 @@ int EventHandler::deactivateModuleHandler(ClientData cdata, Tcl_Interp *irp,
 {
   if(argc != 1)
   {
-    char msg[] = "Usage: deactivateModule";
+    static char msg[] = "Usage: deactivateModule";
     Tcl_SetResult(irp, msg, TCL_STATIC);
     return TCL_ERROR;
   }
@@ -401,7 +389,7 @@ int EventHandler::publishStateEventHandler(ClientData cdata, Tcl_Interp *irp,
 {
   if (argc != 3)
   {
-    char msg[] = "Usage: publishStateEvent <event name> <event msg>";
+    static char msg[] = "Usage: publishStateEvent <event name> <event msg>";
     Tcl_SetResult(irp, msg, TCL_STATIC);
     return TCL_ERROR;
   }
@@ -413,6 +401,46 @@ int EventHandler::publishStateEventHandler(ClientData cdata, Tcl_Interp *irp,
 }
 
 
+int EventHandler::playDtmfHandler(ClientData cdata, Tcl_Interp *irp,
+                                  int argc, const char *argv[])
+{
+  if(argc != 4)
+  {
+    static char msg[] = "Usage: playDtmf <digits> <amp> <milliseconds>";
+    Tcl_SetResult(irp, msg, TCL_STATIC);
+    return TCL_ERROR;
+  }
+  //cout << "EventHandler::playDtmf: " << argv[1] << ", "
+  //    << argv[2] << ", " << argv[3]<< endl;
+  EventHandler *self = static_cast<EventHandler *>(cdata);
+  self->playDtmf(argv[1], atoi(argv[2]), atoi(argv[3]));
+
+  return TCL_OK;
+} /* EventHandler::playDtmfHandler */
+
+
+int EventHandler::injectDtmfHandler(ClientData cdata, Tcl_Interp *irp,
+                                    int argc, const char *argv[])
+{
+  if((argc < 2) or (argc > 3))
+  {
+    static char msg[] = "Usage: injectDtmf <digits> [milliseconds]";
+    Tcl_SetResult(irp, msg, TCL_STATIC);
+    return TCL_ERROR;
+  }
+  string digits(argv[1]);
+  int duration = 100;
+  if (argc == 3)
+  {
+    duration = atoi(argv[2]);
+  }
+  //cout << "EventHandler::injectDtmf: " << digits << ", " << duration << endl;
+  EventHandler *self = static_cast<EventHandler *>(cdata);
+  self->injectDtmf(digits, duration);
+
+  return TCL_OK;
+} /* EventHandler::injectDtmfHandler */
+
 
 /*
  * This file has not been truncated
