@@ -231,7 +231,7 @@ class SineGenerator : public Async::AudioSource
 LocalTx::LocalTx(Config& cfg, const string& name)
   : name(name), cfg(cfg), audio_io(0), is_transmitting(false), txtot(0),
     tx_timeout_occured(false), tx_timeout(0), sine_gen(0), ctcss_enable(false),
-    dtmf_encoder(0), selector(0), dtmf_valve(0), input_handler(0),
+    dtmf_encoder(0), selector(0), dtmf_valve(0), input_handler(0), ptt_ctrl(0),
     audio_valve(0), siglev_sine_gen(0), ptt_hangtimer(0), ptt(0)
 {
 
@@ -320,10 +320,16 @@ bool LocalTx::initialize(void)
   }
   
   int dtmf_tone_amp = -18;
-  if (cfg.getValue(name, "DTMF_TONE_AMP", value))
+  int dtmf_digit_pwr = -15;
+  if (cfg.getValue(name, "DTMF_TONE_AMP", dtmf_tone_amp))
   {
-    dtmf_tone_amp = min(atoi(value.c_str()), 0);
+    cout << "*** WARNING: The DTMF_TONE_AMP configuration variable set in "
+            "transmitter " << name << " is deprecated. Use DTMF_DIGIT_PWR "
+            "instead. To get the same output level uing the new configuration "
+            "variable, add 3dB to the old value." << endl;
+    dtmf_digit_pwr = dtmf_tone_amp + 3;
   }
+  cfg.getValue(name, "DTMF_DIGIT_PWR", dtmf_digit_pwr);
   
   audio_io = new AudioIO(audio_dev, audio_channel);
   // FIXME: Check that the audio device has been correctly initialized
@@ -429,7 +435,8 @@ bool LocalTx::initialize(void)
 #if 1
     // Filter out high frequencies generated by the previous clipping
 #if (INTERNAL_SAMPLE_RATE == 16000)
-  AudioFilter *splatter_filter = new AudioFilter("LpBu10/5500");
+  //AudioFilter *splatter_filter = new AudioFilter("LpBu10/5500");
+  AudioFilter *splatter_filter = new AudioFilter("LpCh9/-0.05/5500");
 #else
   AudioFilter *splatter_filter = new AudioFilter("LpBu20/3500");
 #endif
@@ -457,9 +464,9 @@ bool LocalTx::initialize(void)
   dtmf_encoder = new DtmfEncoder(INTERNAL_SAMPLE_RATE);
   dtmf_encoder->allDigitsSent.connect(
       mem_fun(*this, &LocalTx::allDtmfDigitsSent));
-  dtmf_encoder->setToneLength(dtmf_tone_length);
-  dtmf_encoder->setToneSpacing(dtmf_tone_spacing);
-  dtmf_encoder->setToneAmplitude(dtmf_tone_amp);
+  dtmf_encoder->setDigitDuration(dtmf_tone_length);
+  dtmf_encoder->setDigitSpacing(dtmf_tone_spacing);
+  dtmf_encoder->setDigitPower(dtmf_digit_pwr);
   
     // Create a valve so that we can control when to transmit DTMF
   dtmf_valve = new AudioValve;
@@ -475,6 +482,15 @@ bool LocalTx::initialize(void)
   prev_src->registerSink(ptt_ctrl, true);
   prev_src = ptt_ctrl;
 
+  float master_gain = 0.0f;
+  if (cfg.getValue(name, "MASTER_GAIN", master_gain))
+  {
+    AudioAmp *master_gain_stage = new AudioAmp;
+    master_gain_stage->setGain(master_gain);
+    prev_src->registerSink(master_gain_stage, true);
+    prev_src = master_gain_stage;
+  }
+
 #if (INTERNAL_SAMPLE_RATE != 16000)  
   if (audio_io->sampleRate() > 8000)
   {
