@@ -205,7 +205,7 @@ void NetTrxTcpClient::sendMsg(Msg *msg)
 
 NetTrxTcpClient::NetTrxTcpClient(const std::string& remote_host,
       	      	      	      	 uint16_t remote_port, size_t recv_buf_len)
-  : TcpClient(remote_host, remote_port, recv_buf_len), recv_cnt(0),
+  : TcpClient<>(remote_host, remote_port, recv_buf_len), recv_cnt(0),
     recv_exp(0), reconnect_timer(0), last_msg_timestamp(), heartbeat_timer(0),
     user_cnt(0), state(STATE_DISC), disc_reason(DR_SYSTEM_ERROR)
 {
@@ -472,15 +472,15 @@ void NetTrxTcpClient::sendMsgP(Msg *msg)
   {
     if (written == -1)
     {
-      cerr << "*** ERROR: TCP write error\n";
+      cerr << "*** ERROR: TCP write error: " << strerror(errno) << "\n";
     }
     else
     {
       cerr << "*** ERROR: TCP transmit buffer overflow. Disconnecting from "
          << remoteHost().toString() << ":" << remotePort() << "...\n";
-      disconnect();
-      disconnected(this, TcpConnection::DR_ORDERED_DISCONNECT);
     }
+    disconnect();
+    disconnected(this, TcpConnection::DR_ORDERED_DISCONNECT);
   }
   
   delete msg;
